% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/layers.core.R
\name{Activation}
\alias{Activation}
\title{Applies an activation function to an output.}
\usage{
Activation(activation, input_shape = NULL)
}
\arguments{
\item{activation}{name of activation function to use. See Details
for possible options.}

\item{input_shape}{only need when first layer of a model; sets the input shape
of the data}
}
\description{
Applies an activation function to an output.
}
\details{
Possible activations include 'softmax', 'elu', 'softplus', 'softsign',
         'relu', 'tanh', 'sigmoid', 'hard_sigmoid', 'linear'. You may also
         set this equal to any of the outputs from an \link{AdvancedActivation}.
}
\examples{
if (run_examples()) {
X_train <- matrix(rnorm(100 * 10), nrow = 100)
Y_train <- to_categorical(matrix(sample(0:2, 100, TRUE), ncol = 1), 3)

mod <- Sequential()
mod$add(Dense(units = 50, input_shape = dim(X_train)[2]))
mod$add(Dropout(rate = 0.5))
mod$add(Activation("relu"))
mod$add(Dense(units = 3))
mod$add(ActivityRegularization(l1 = 1))
mod$add(Activation("softmax"))
keras_compile(mod,  loss = 'categorical_crossentropy', optimizer = RMSprop())

keras_fit(mod, X_train, Y_train, batch_size = 32, epochs = 5,
          verbose = 0, validation_split = 0.2)
}
}
\references{
Chollet, Francois. 2015. \href{https://keras.io/}{Keras: Deep Learning library for Theano and TensorFlow}.
}
\author{
Taylor B. Arnold, \email{taylor.arnold@acm.org}
}
